Please see [https://docs.mlcommons.org/cm4mlops/scripts/Compiler-automation/get-llvm](https://docs.mlcommons.org/cm4mlops/scripts/Compiler-automation/get-llvm) for the documentation of this CM script.
